.. polytopewalk documentation master file, created by
   sphinx-quickstart on Tue May  9 22:50:40 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to polytopewalk's documentation!
=======================================

.. toctree::
   :caption: User Guide

   installation
   support


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


Docs
====